@@ -67,6 +67,7 @@ C   3D median smoother of y with neighborhood defined by ind
 C   results in yout
 C   size of work needs to be 2*nind
 C
+      use omp_lib
       implicit none
       integer n1,n2,n3,nind,ind(3,nind),ncores
       integer mask(n1,n2,n3)
@@ -74,8 +75,8 @@ C
       integer i1,i2,i3,j1,j2,j3,j,k,thrednr
       double precision fmedian
       external fmedian
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
+C!$      integer omp_get_thread_num
+C!$      external omp_get_thread_num
       thrednr = 1
 C$OMP PARALLEL DEFAULT(SHARED)
 C$OMP& PRIVATE(i1,i2,i3,j1,j2,j3,j,k,thrednr)
@@ -138,6 +139,7 @@ C   location weights in w(i)
 C   ind(.,i)[1:3] are j1-i1,j2-i2 and j3-i3 respectively
 C   wad, sad - array for weights>0 and corresponding observed s
 C
+      use omp_lib
       implicit none
       integer n1,n2,n3,nw,ind(3,nw),nthreds,iL,nfb
       integer mask(n1,n2,n3)
@@ -148,8 +150,8 @@ C
       integer i1,i2,i3,j1,j2,j3,i,j,jj,n,maxit,thrednr
       double precision z,sw,sws,sws2,sj,thi,wj,kval,fnsi,sgi,tol,low,up,
      1       fmin,sgi2,vz,thi2,thj2,fnsj,thj,nii
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
+C!$      integer omp_get_thread_num
+C!$      external omp_get_thread_num
       n = n1*n2*n3
       thrednr = 1
       tol=1d-5
@@ -271,6 +273,7 @@ C   location weights in w(i)
 C   ind(.,i)[1:3] are j1-i1,j2-i2 and j3-i3 respectively
 C   wad, sad - array for weights>0 and corresponding observed s
 C
+      use omp_lib
       implicit none
       integer n1,n2,n3,nw,ind(3,nw)
       integer mask(n1,n2,n3)
@@ -278,8 +281,8 @@ C
      1 th(n1,n2,n3),sigman(n1*n2*n3),lambda,w(nw),sigma(n1,n2,n3),minni
       integer i1,i2,i3,j1,j2,j3,i,j,n,thrednr
       double precision z,sw,sws,sws2,sj,thi,wj,kval,sgi
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
+C!$      integer omp_get_thread_num
+C!$      external omp_get_thread_num
       n = n1*n2*n3
       thrednr = 1
 C  precompute values of lgamma(corrected df/2) in each voxel
@@ -439,6 +442,7 @@ C   ind(.,i) contains coordinate indormation corresponding to positive
 C   location weights in w(i)
 C   ind(.,i)[1:5] are j1-i1,j2-i2,j3-i3, i4 and j4 respectively
 C
+      use omp_lib
       implicit none
       integer n1,n2,n3,nw,ind(3,nw),nthreds
       integer mask(n1,n2,n3)
@@ -447,8 +451,8 @@ C
      2       sigma,wad(nw,nthreds)
       integer i1,i2,i3,j1,j2,j3,i,j,n,thrednr
       double precision z,sw,sw2,swy,swy2,yj,thi,wj,kval,cw,fnsi
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
+C!$      integer omp_get_thread_num
+C!$      external omp_get_thread_num
       n = n1*n2*n3
       thrednr = 1
 C  precompute values of lgamma(corrected df/2) in each voxel
